package com.tistory.antop.mybatis.handler;

import java.sql.CallableStatement;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Timestamp;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Date;

import org.apache.ibatis.type.JdbcType;
import org.apache.ibatis.type.TypeHandler;
import org.apache.log4j.Logger;

public class TimestampTypeHandler implements TypeHandler<Date> {

	// logger
	private Logger logger = Logger.getLogger(getClass());
	// simple date format
	private SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");

	public Date getResult(ResultSet rs, String columnName) throws SQLException {
		String s = rs.getString(columnName);
		return parseDate(s);
	}

	public Date getResult(ResultSet rs, int columnIndex) throws SQLException {
		String s = rs.getString(columnIndex);
		return parseDate(s);
	}

	public Date getResult(CallableStatement cs, int columnIndex)
			throws SQLException {
		String s = cs.getString(columnIndex);
		return parseDate(s);
	}

	public void setParameter(PreparedStatement ps, int i, Date d,
			JdbcType jdbcType) throws SQLException {
		ps.setTimestamp(i, new Timestamp(d.getTime()));
	}

	// string "yyyy-MM-dd HH:mm:ss" -> date
	private Date parseDate(String s) {

		if (s == null) {
			return null;
		}

		s = s.trim();

		if (s.length() == 0) {
			return null;
		}

		Date d = null;
		try {
			d = sdf.parse(s);
		} catch (ParseException e) {
			logger.warn(e.getMessage());
		}

		if (logger.isDebugEnabled()) {
			logger.info("string [\"" + s + "\"] -> date [" + d + "]");
		}

		return d;
	}

}
